==> payline-java-sdk-4.68-sources.jar: com/payline/ws/model/GetWebPaymentDetailsResponse.java <==

package com.payline.ws.model;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * 
 * 							This element is the reponse from the
 * 							doWebPayment
 * 							method
 * 						
 * 
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="result" type="{http://obj.ws.payline.experian.com}result"/&gt;
 *         &lt;element name="transaction" type="{http://obj.ws.payline.experian.com}transaction"/&gt;
 *         &lt;element name="payment" type="{http://obj.ws.payline.experian.com}payment"/&gt;
 *         &lt;element name="authorization" type="{http://obj.ws.payline.experian.com}authorization"/&gt;
 *         &lt;element name="privateDataList" type="{http://obj.ws.payline.experian.com}privateDataList" minOccurs="0"/&gt;
 *         &lt;element name="paymentRecordId" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *         &lt;element name="billingRecordList" type="{http://obj.ws.payline.experian.com}billingRecordList" minOccurs="0"/&gt;
 *         &lt;element name="authentication3DSecure" type="{http://obj.ws.payline.experian.com}authentication3DSecure" minOccurs="0"/&gt;
 *         &lt;element name="card" type="{http://obj.ws.payline.experian.com}cardOut"/&gt;
 *         &lt;element name="extendedCard" type="{http://obj.ws.payline.experian.com}extendedCardType" minOccurs="0"/&gt;
 *         &lt;element name="order" type="{http://obj.ws.payline.experian.com}order"/&gt;
 *         &lt;element name="paymentAdditionalList" type="{http://obj.ws.payline.experian.com}paymentAdditionalList" minOccurs="0"/&gt;
 *         &lt;element name="media" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *         &lt;element name="numberOfAttempt" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *         &lt;element name="wallet" type="{http://obj.ws.payline.experian.com}wallet" minOccurs="0"/&gt;
 *         &lt;element name="contractNumberWalletList" type="{http://obj.ws.payline.experian.com}contractNumberWalletList" minOccurs="0"/&gt;
 *         &lt;element name="contractNumber" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *         &lt;element name="bankAccountData" type="{http://obj.ws.payline.experian.com}bankAccountData"/&gt;
 *         &lt;element name="subMerchant" type="{http://obj.ws.payline.experian.com}subMerchant"/&gt;
 *         &lt;element name="buyer" type="{http://obj.ws.payline.experian.com}buyer"/&gt;
 *         &lt;element name="linkedTransactionId" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "result",
    "transaction",
    "payment",
    "authorization",
    "privateDataList",
    "paymentRecordId",
    "billingRecordList",
    "authentication3DSecure",
    "card",
    "extendedCard",
    "order",
    "paymentAdditionalList",
    "media",
    "numberOfAttempt",
    "wallet",
    "contractNumberWalletList",
    "contractNumber",
    "bankAccountData",
    "subMerchant",
    "buyer",
    "linkedTransactionId"
})
@XmlRootElement(name = "getWebPaymentDetailsResponse")
public class GetWebPaymentDetailsResponse {

    @XmlElement(required = true)
    protected Result result;
    @XmlElement(required = true)
    protected Transaction transaction;
    @XmlElement(required = true)
    protected Payment payment;
    @XmlElement(required = true)
    protected Authorization authorization;
    @XmlElement(nillable = true)
    protected PrivateDataList privateDataList;
    @XmlElement(nillable = true)
    protected String paymentRecordId;
    @XmlElement(nillable = true)
    protected BillingRecordList billingRecordList;
    @XmlElement(nillable = true)
    protected Authentication3DSecure authentication3DSecure;
    @XmlElement(required = true)
    protected CardOut card;
    protected ExtendedCardType extendedCard;
    @XmlElement(required = true)
    protected Order order;
    @XmlElement(nillable = true)
    protected PaymentAdditionalList paymentAdditionalList;
    @XmlElement(nillable = true)
    protected String media;
    @XmlElement(nillable = true)
    protected String numberOfAttempt;
    @XmlElement(nillable = true)
    protected Wallet wallet;
    @XmlElement(nillable = true)
    protected ContractNumberWalletList contractNumberWalletList;
    protected String contractNumber;
    @XmlElement(required = true, nillable = true)
    protected BankAccountData bankAccountData;
    @XmlElement(required = true, nillable = true)
    protected SubMerchant subMerchant;
    @XmlElement(required = true, nillable = true)
    protected Buyer buyer;
    @XmlElement(required = true, nillable = true)
    protected String linkedTransactionId;

    /**
     * Gets the value of the result property.
     * 
     * @return
     *     possible object is
     *     {@link Result }
     *     
     */
    public Result getResult() {
        return result;
    }

    /**
     * Sets the value of the result property.
     * 
     * @param value
     *     allowed object is
     *     {@link Result }
     *     
     */
    public void setResult(Result value) {
        this.result = value;
    }

    /**
     * Gets the value of the transaction property.
     * 
     * @return
     *     possible object is
     *     {@link Transaction }
     *     
     */
    public Transaction getTransaction() {
        return transaction;
    }

    /**
     * Sets the value of the transaction property.
     * 
     * @param value
     *     allowed object is
     *     {@link Transaction }
     *     
     */
    public void setTransaction(Transaction value) {
        this.transaction = value;
    }

    /**
     * Gets the value of the payment property.
     * 
     * @return
     *     possible object is
     *     {@link Payment }
     *     
     */
    public Payment getPayment() {
        return payment;
    }

    /**
     * Sets the value of the payment property.
     * 
     * @param value
     *     allowed object is
     *     {@link Payment }
     *     
     */
    public void setPayment(Payment value) {
        this.payment = value;
    }

    /**
     * Gets the value of the authorization property.
     * 
     * @return
     *     possible object is
     *     {@link Authorization }
     *     
     */
    public Authorization getAuthorization() {
        return authorization;
    }

    /**
     * Sets the value of the authorization property.
     * 
     * @param value
     *     allowed object is
     *     {@link Authorization }
     *     
     */
    public void setAuthorization(Authorization value) {
        this.authorization = value;
    }

    /**
     * Gets the value of the privateDataList property.
     * 
     * @return
     *     possible object is
     *     {@link PrivateDataList }
     *     
     */
    public PrivateDataList getPrivateDataList() {
        return privateDataList;
    }

    /**
     * Sets the value of the privateDataList property.
     * 
     * @param value
     *     allowed object is
     *     {@link PrivateDataList }
     *     
     */
    public void setPrivateDataList(PrivateDataList value) {
        this.privateDataList = value;
    }

    /**
     * Gets the value of the paymentRecordId property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPaymentRecordId() {
        return paymentRecordId;
    }

    /**
     * Sets the value of the paymentRecordId property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPaymentRecordId(String value) {
        this.paymentRecordId = value;
    }

    /**
     * Gets the value of the billingRecordList property.
     * 
     * @return
     *     possible object is
     *     {@link BillingRecordList }
     *     
     */
    public BillingRecordList getBillingRecordList() {
        return billingRecordList;
    }

    /**
     * Sets the value of the billingRecordList property.
     * 
     * @param value
     *     allowed object is
     *     {@link BillingRecordList }
     *     
     */
    public void setBillingRecordList(BillingRecordList value) {
        this.billingRecordList = value;
    }

    /**
     * Gets the value of the authentication3DSecure property.
     * 
     * @return
     *     possible object is
     *     {@link Authentication3DSecure }
     *     
     */
    public Authentication3DSecure getAuthentication3DSecure() {
        return authentication3DSecure;
    }

    /**
     * Sets the value of the authentication3DSecure property.
     * 
     * @param value
     *     allowed object is
     *     {@link Authentication3DSecure }
     *     
     */
    public void setAuthentication3DSecure(Authentication3DSecure value) {
        this.authentication3DSecure = value;
    }

    /**
     * Gets the value of the card property.
     * 
     * @return
     *     possible object is
     *     {@link CardOut }
     *     
     */
    public CardOut getCard() {
        return card;
    }

    /**
     * Sets the value of the card property.
     * 
     * @param value
     *     allowed object is
     *     {@link CardOut }
     *     
     */
    public void setCard(CardOut value) {
        this.card = value;
    }

    /**
     * Gets the value of the extendedCard property.
     * 
     * @return
     *     possible object is
     *     {@link ExtendedCardType }
     *     
     */
    public ExtendedCardType getExtendedCard() {
        return extendedCard;
    }

    /**
     * Sets the value of the extendedCard property.
     * 
     * @param value
     *     allowed object is
     *     {@link ExtendedCardType }
     *     
     */
    public void setExtendedCard(ExtendedCardType value) {
        this.extendedCard = value;
    }

    /**
     * Gets the value of the order property.
     * 
     * @return
     *     possible object is
     *     {@link Order }
     *     
     */
    public Order getOrder() {
        return order;
    }

    /**
     * Sets the value of the order property.
     * 
     * @param value
     *     allowed object is
     *     {@link Order }
     *     
     */
    public void setOrder(Order value) {
        this.order = value;
    }

    /**
     * Gets the value of the paymentAdditionalList property.
     * 
     * @return
     *     possible object is
     *     {@link PaymentAdditionalList }
     *     
     */
    public PaymentAdditionalList getPaymentAdditionalList() {
        return paymentAdditionalList;
    }

    /**
     * Sets the value of the paymentAdditionalList property.
     * 
     * @param value
     *     allowed object is
     *     {@link PaymentAdditionalList }
     *     
     */
    public void setPaymentAdditionalList(PaymentAdditionalList value) {
        this.paymentAdditionalList = value;
    }

    /**
     * Gets the value of the media property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMedia() {
        return media;
    }

    /**
     * Sets the value of the media property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMedia(String value) {
        this.media = value;
    }

    /**
     * Gets the value of the numberOfAttempt property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getNumberOfAttempt() {
        return numberOfAttempt;
    }

    /**
     * Sets the value of the numberOfAttempt property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setNumberOfAttempt(String value) {
        this.numberOfAttempt = value;
    }

    /**
     * Gets the value of the wallet property.
     * 
     * @return
     *     possible object is
     *     {@link Wallet }
     *     
     */
    public Wallet getWallet() {
        return wallet;
    }

    /**
     * Sets the value of the wallet property.
     * 
     * @param value
     *     allowed object is
     *     {@link Wallet }
     *     
     */
    public void setWallet(Wallet value) {
        this.wallet = value;
    }

    /**
     * Gets the value of the contractNumberWalletList property.
     * 
     * @return
     *     possible object is
     *     {@link ContractNumberWalletList }
     *     
     */
    public ContractNumberWalletList getContractNumberWalletList() {
        return contractNumberWalletList;
    }

    /**
     * Sets the value of the contractNumberWalletList property.
     * 
     * @param value
     *     allowed object is
     *     {@link ContractNumberWalletList }
     *     
     */
    public void setContractNumberWalletList(ContractNumberWalletList value) {
        this.contractNumberWalletList = value;
    }

    /**
     * Gets the value of the contractNumber property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getContractNumber() {
        return contractNumber;
    }

    /**
     * Sets the value of the contractNumber property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setContractNumber(String value) {
        this.contractNumber = value;
    }

    /**
     * Gets the value of the bankAccountData property.
     * 
     * @return
     *     possible object is
     *     {@link BankAccountData }
     *     
     */
    public BankAccountData getBankAccountData() {
        return bankAccountData;
    }

    /**
     * Sets the value of the bankAccountData property.
     * 
     * @param value
     *     allowed object is
     *     {@link BankAccountData }
     *     
     */
    public void setBankAccountData(BankAccountData value) {
        this.bankAccountData = value;
    }

    /**
     * Gets the value of the subMerchant property.
     * 
     * @return
     *     possible object is
     *     {@link SubMerchant }
     *     
     */
    public SubMerchant getSubMerchant() {
        return subMerchant;
    }

    /**
     * Sets the value of the subMerchant property.
     * 
     * @param value
     *     allowed object is
     *     {@link SubMerchant }
     *     
     */
    public void setSubMerchant(SubMerchant value) {
        this.subMerchant = value;
    }

    /**
     * Gets the value of the buyer property.
     * 
     * @return
     *     possible object is
     *     {@link Buyer }
     *     
     */
    public Buyer getBuyer() {
        return buyer;
    }

    /**
     * Sets the value of the buyer property.
     * 
     * @param value
     *     allowed object is
     *     {@link Buyer }
     *     
     */
    public void setBuyer(Buyer value) {
        this.buyer = value;
    }

    /**
     * Gets the value of the linkedTransactionId property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLinkedTransactionId() {
        return linkedTransactionId;
    }

    /**
     * Sets the value of the linkedTransactionId property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLinkedTransactionId(String value) {
        this.linkedTransactionId = value;
    }

}

==> payline-java-sdk-4.71-sources.jar: com/payline/ws/model/GetWebPaymentDetailsResponse.java <==

package com.payline.ws.model;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * 
 * 							This element is the reponse from the
 * 							doWebPayment
 * 							method
 * 						
 * 
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="result" type="{http://obj.ws.payline.experian.com}result"/&gt;
 *         &lt;element name="transaction" type="{http://obj.ws.payline.experian.com}transaction"/&gt;
 *         &lt;element name="payment" type="{http://obj.ws.payline.experian.com}payment"/&gt;
 *         &lt;element name="authorization" type="{http://obj.ws.payline.experian.com}authorization"/&gt;
 *         &lt;element name="privateDataList" type="{http://obj.ws.payline.experian.com}privateDataList" minOccurs="0"/&gt;
 *         &lt;element name="paymentRecordId" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *         &lt;element name="billingRecordList" type="{http://obj.ws.payline.experian.com}billingRecordList" minOccurs="0"/&gt;
 *         &lt;element name="authentication3DSecure" type="{http://obj.ws.payline.experian.com}authentication3DSecure" minOccurs="0"/&gt;
 *         &lt;element name="card" type="{http://obj.ws.payline.experian.com}cardOut"/&gt;
 *         &lt;element name="extendedCard" type="{http://obj.ws.payline.experian.com}extendedCardType" minOccurs="0"/&gt;
 *         &lt;element name="order" type="{http://obj.ws.payline.experian.com}order"/&gt;
 *         &lt;element name="paymentAdditionalList" type="{http://obj.ws.payline.experian.com}paymentAdditionalList" minOccurs="0"/&gt;
 *         &lt;element name="media" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *         &lt;element name="numberOfAttempt" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *         &lt;element name="wallet" type="{http://obj.ws.payline.experian.com}wallet" minOccurs="0"/&gt;
 *         &lt;element name="contractNumberWalletList" type="{http://obj.ws.payline.experian.com}contractNumberWalletList" minOccurs="0"/&gt;
 *         &lt;element name="contractNumber" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *         &lt;element name="bankAccountData" type="{http://obj.ws.payline.experian.com}bankAccountData"/&gt;
 *         &lt;element name="subMerchant" type="{http://obj.ws.payline.experian.com}subMerchant"/&gt;
 *         &lt;element name="buyer" type="{http://obj.ws.payline.experian.com}buyer"/&gt;
 *         &lt;element name="linkedTransactionId" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="travelFileNumber" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "result",
    "transaction",
    "payment",
    "authorization",
    "privateDataList",
    "paymentRecordId",
    "billingRecordList",
    "authentication3DSecure",
    "card",
    "extendedCard",
    "order",
    "paymentAdditionalList",
    "media",
    "numberOfAttempt",
    "wallet",
    "contractNumberWalletList",
    "contractNumber",
    "bankAccountData",
    "subMerchant",
    "buyer",
    "linkedTransactionId",
    "travelFileNumber"
})
@XmlRootElement(name = "getWebPaymentDetailsResponse")
public class GetWebPaymentDetailsResponse {

    @XmlElement(required = true)
    protected Result result;
    @XmlElement(required = true)
    protected Transaction transaction;
    @XmlElement(required = true)
    protected Payment payment;
    @XmlElement(required = true)
    protected Authorization authorization;
    @XmlElement(nillable = true)
    protected PrivateDataList privateDataList;
    @XmlElement(nillable = true)
    protected String paymentRecordId;
    @XmlElement(nillable = true)
    protected BillingRecordList billingRecordList;
    @XmlElement(nillable = true)
    protected Authentication3DSecure authentication3DSecure;
    @XmlElement(required = true)
    protected CardOut card;
    protected ExtendedCardType extendedCard;
    @XmlElement(required = true)
    protected Order order;
    @XmlElement(nillable = true)
    protected PaymentAdditionalList paymentAdditionalList;
    @XmlElement(nillable = true)
    protected String media;
    @XmlElement(nillable = true)
    protected String numberOfAttempt;
    @XmlElement(nillable = true)
    protected Wallet wallet;
    @XmlElement(nillable = true)
    protected ContractNumberWalletList contractNumberWalletList;
    protected String contractNumber;
    @XmlElement(required = true, nillable = true)
    protected BankAccountData bankAccountData;
    @XmlElement(required = true, nillable = true)
    protected SubMerchant subMerchant;
    @XmlElement(required = true, nillable = true)
    protected Buyer buyer;
    @XmlElement(required = true, nillable = true)
    protected String linkedTransactionId;
    @XmlElement(nillable = true)
    protected String travelFileNumber;

    /**
     * Gets the value of the result property.
     * 
     * @return
     *     possible object is
     *     {@link Result }
     *     
     */
    public Result getResult() {
        return result;
    }

    /**
     * Sets the value of the result property.
     * 
     * @param value
     *     allowed object is
     *     {@link Result }
     *     
     */
    public void setResult(Result value) {
        this.result = value;
    }

    /**
     * Gets the value of the transaction property.
     * 
     * @return
     *     possible object is
     *     {@link Transaction }
     *     
     */
    public Transaction getTransaction() {
        return transaction;
    }

    /**
     * Sets the value of the transaction property.
     * 
     * @param value
     *     allowed object is
     *     {@link Transaction }
     *     
     */
    public void setTransaction(Transaction value) {
        this.transaction = value;
    }

    /**
     * Gets the value of the payment property.
     * 
     * @return
     *     possible object is
     *     {@link Payment }
     *     
     */
    public Payment getPayment() {
        return payment;
    }

    /**
     * Sets the value of the payment property.
     * 
     * @param value
     *     allowed object is
     *     {@link Payment }
     *     
     */
    public void setPayment(Payment value) {
        this.payment = value;
    }

    /**
     * Gets the value of the authorization property.
     * 
     * @return
     *     possible object is
     *     {@link Authorization }
     *     
     */
    public Authorization getAuthorization() {
        return authorization;
    }

    /**
     * Sets the value of the authorization property.
     * 
     * @param value
     *     allowed object is
     *     {@link Authorization }
     *     
     */
    public void setAuthorization(Authorization value) {
        this.authorization = value;
    }

    /**
     * Gets the value of the privateDataList property.
     * 
     * @return
     *     possible object is
     *     {@link PrivateDataList }
     *     
     */
    public PrivateDataList getPrivateDataList() {
        return privateDataList;
    }

    /**
     * Sets the value of the privateDataList property.
     * 
     * @param value
     *     allowed object is
     *     {@link PrivateDataList }
     *     
     */
    public void setPrivateDataList(PrivateDataList value) {
        this.privateDataList = value;
    }

    /**
     * Gets the value of the paymentRecordId property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPaymentRecordId() {
        return paymentRecordId;
    }

    /**
     * Sets the value of the paymentRecordId property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPaymentRecordId(String value) {
        this.paymentRecordId = value;
    }

    /**
     * Gets the value of the billingRecordList property.
     * 
     * @return
     *     possible object is
     *     {@link BillingRecordList }
     *     
     */
    public BillingRecordList getBillingRecordList() {
        return billingRecordList;
    }

    /**
     * Sets the value of the billingRecordList property.
     * 
     * @param value
     *     allowed object is
     *     {@link BillingRecordList }
     *     
     */
    public void setBillingRecordList(BillingRecordList value) {
        this.billingRecordList = value;
    }

    /**
     * Gets the value of the authentication3DSecure property.
     * 
     * @return
     *     possible object is
     *     {@link Authentication3DSecure }
     *     
     */
    public Authentication3DSecure getAuthentication3DSecure() {
        return authentication3DSecure;
    }

    /**
     * Sets the value of the authentication3DSecure property.
     * 
     * @param value
     *     allowed object is
     *     {@link Authentication3DSecure }
     *     
     */
    public void setAuthentication3DSecure(Authentication3DSecure value) {
        this.authentication3DSecure = value;
    }

    /**
     * Gets the value of the card property.
     * 
     * @return
     *     possible object is
     *     {@link CardOut }
     *     
     */
    public CardOut getCard() {
        return card;
    }

    /**
     * Sets the value of the card property.
     * 
     * @param value
     *     allowed object is
     *     {@link CardOut }
     *     
     */
    public void setCard(CardOut value) {
        this.card = value;
    }

    /**
     * Gets the value of the extendedCard property.
     * 
     * @return
     *     possible object is
     *     {@link ExtendedCardType }
     *     
     */
    public ExtendedCardType getExtendedCard() {
        return extendedCard;
    }

    /**
     * Sets the value of the extendedCard property.
     * 
     * @param value
     *     allowed object is
     *     {@link ExtendedCardType }
     *     
     */
    public void setExtendedCard(ExtendedCardType value) {
        this.extendedCard = value;
    }

    /**
     * Gets the value of the order property.
     * 
     * @return
     *     possible object is
     *     {@link Order }
     *     
     */
    public Order getOrder() {
        return order;
    }

    /**
     * Sets the value of the order property.
     * 
     * @param value
     *     allowed object is
     *     {@link Order }
     *     
     */
    public void setOrder(Order value) {
        this.order = value;
    }

    /**
     * Gets the value of the paymentAdditionalList property.
     * 
     * @return
     *     possible object is
     *     {@link PaymentAdditionalList }
     *     
     */
    public PaymentAdditionalList getPaymentAdditionalList() {
        return paymentAdditionalList;
    }

    /**
     * Sets the value of the paymentAdditionalList property.
     * 
     * @param value
     *     allowed object is
     *     {@link PaymentAdditionalList }
     *     
     */
    public void setPaymentAdditionalList(PaymentAdditionalList value) {
        this.paymentAdditionalList = value;
    }

    /**
     * Gets the value of the media property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMedia() {
        return media;
    }

    /**
     * Sets the value of the media property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMedia(String value) {
        this.media = value;
    }

    /**
     * Gets the value of the numberOfAttempt property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getNumberOfAttempt() {
        return numberOfAttempt;
    }

    /**
     * Sets the value of the numberOfAttempt property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setNumberOfAttempt(String value) {
        this.numberOfAttempt = value;
    }

    /**
     * Gets the value of the wallet property.
     * 
     * @return
     *     possible object is
     *     {@link Wallet }
     *     
     */
    public Wallet getWallet() {
        return wallet;
    }

    /**
     * Sets the value of the wallet property.
     * 
     * @param value
     *     allowed object is
     *     {@link Wallet }
     *     
     */
    public void setWallet(Wallet value) {
        this.wallet = value;
    }

    /**
     * Gets the value of the contractNumberWalletList property.
     * 
     * @return
     *     possible object is
     *     {@link ContractNumberWalletList }
     *     
     */
    public ContractNumberWalletList getContractNumberWalletList() {
        return contractNumberWalletList;
    }

    /**
     * Sets the value of the contractNumberWalletList property.
     * 
     * @param value
     *     allowed object is
     *     {@link ContractNumberWalletList }
     *     
     */
    public void setContractNumberWalletList(ContractNumberWalletList value) {
        this.contractNumberWalletList = value;
    }

    /**
     * Gets the value of the contractNumber property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getContractNumber() {
        return contractNumber;
    }

    /**
     * Sets the value of the contractNumber property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setContractNumber(String value) {
        this.contractNumber = value;
    }

    /**
     * Gets the value of the bankAccountData property.
     * 
     * @return
     *     possible object is
     *     {@link BankAccountData }
     *     
     */
    public BankAccountData getBankAccountData() {
        return bankAccountData;
    }

    /**
     * Sets the value of the bankAccountData property.
     * 
     * @param value
     *     allowed object is
     *     {@link BankAccountData }
     *     
     */
    public void setBankAccountData(BankAccountData value) {
        this.bankAccountData = value;
    }

    /**
     * Gets the value of the subMerchant property.
     * 
     * @return
     *     possible object is
     *     {@link SubMerchant }
     *     
     */
    public SubMerchant getSubMerchant() {
        return subMerchant;
    }

    /**
     * Sets the value of the subMerchant property.
     * 
     * @param value
     *     allowed object is
     *     {@link SubMerchant }
     *     
     */
    public void setSubMerchant(SubMerchant value) {
        this.subMerchant = value;
    }

    /**
     * Gets the value of the buyer property.
     * 
     * @return
     *     possible object is
     *     {@link Buyer }
     *     
     */
    public Buyer getBuyer() {
        return buyer;
    }

    /**
     * Sets the value of the buyer property.
     * 
     * @param value
     *     allowed object is
     *     {@link Buyer }
     *     
     */
    public void setBuyer(Buyer value) {
        this.buyer = value;
    }

    /**
     * Gets the value of the linkedTransactionId property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLinkedTransactionId() {
        return linkedTransactionId;
    }

    /**
     * Sets the value of the linkedTransactionId property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLinkedTransactionId(String value) {
        this.linkedTransactionId = value;
    }

    /**
     * Gets the value of the travelFileNumber property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTravelFileNumber() {
        return travelFileNumber;
    }

    /**
     * Sets the value of the travelFileNumber property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTravelFileNumber(String value) {
        this.travelFileNumber = value;
    }

}
